@@ -6,7 +6,7 @@ use strict;
 use Cf qw($CACHEDIR $LOGDIR $LOGSUB $POPHOME $WDESCR $DEFAULTKLASSE);
 use Dbase::Help;
 use Dbase::Globals;
-use Dbase::Globals qw(find_dienst);
+use Dbase::Globals qw(find_dienst list_descr);
 use Dbase::IP;
 use Getopt::Std;
 use Time::Local;
@@ -399,6 +399,46 @@ sub read_services() {
 	}
 }
 
+sub read_mail() {
+	my $self = shift;
+
+	$0=$self->{'zb'}." mail";
+	DoSelect {
+		my ($name, $cust, $typ) = @_;
+        $name = '@' . $name unless $name =~ /\@/;
+		$self->{'hash_uucp'}{$name} = $cust
+			unless exists $self->{'hash_uucp'}{$name};
+	} <<_;
+SELECT quelle, kunde, typ
+  FROM mailrules
+ WHERE quelle IS NOT NULL
+_
+}
+
+sub read_pppoe() {
+	my $self = shift;
+
+	# Templates holen
+	my %Templates;
+	list_descr(
+		pppoe => undef, undef,
+		sub {
+			my ( $ident, $num_id, $name, $info ) = @_;
+			$Templates{$num_id} = { name => $name, template => $info };
+		}
+	);
+
+	DoSelect {
+		my ( $cust, $name, $pppoe ) = @_;
+
+		my $info = $Templates{$pppoe}->{template};
+		$info =~ s/\[%\s*person\.user\s*%\]/$name/;
+		$info =~ s/\@.*//;
+		$self->{'hash_uucp'}{$info} = $cust
+			unless exists $self->{'hash_uucp'}{$info};
+	} "SELECT kunde, user, pppoe FROM person WHERE pppoe IS NOT NULL";
+
+}
 
 ### tested_name -> class
 sub who_dom {
@@ -797,6 +837,8 @@ sub new {
 		$def = $self->read_domainkunde if $req eq "domain" or $req eq "domainkunde";
 		$def = $self->read_ipkunde if $req eq "ip" or $req eq "ipkunde";
 		$def = $self->read_ip_sub($1) if $req =~ /^ip_(.+)/;
+		$def = $self->read_mail if $req eq "mail";
+		$def = $self->read_pppoe if $req eq "pppoe";
 		fehler "Unbekannter Key: '$req'\n" unless defined $def;
 	}
 
@@ -804,6 +846,7 @@ sub new {
 }
 
 sub DESTROY {
+	local $@;
 	my $self = shift;
 
 	foreach my $fh (values %{$self->{'logfile'}}) {
