@@ -442,7 +442,11 @@ sub dbfehler {
 	if($err =~ /Lost connection to MySQL server during query/) {
 		nfehler "Das dauerte zu lang. $nerr","Die Datenbankverbindung wurde getrennt!";
 	}
-	fehler "[$$] Datenbankfehler $nerr \@ $hi: $err",@msg,"* last:".$self->{'last_time'},$self->{'last_stmt'}
+	fehler "[$$] Datenbankfehler $nerr \@ $hi: $err",
+		@msg,
+		"* last:".$self->{'last_time'},
+		'Datenbank: '.$self->{'DATAUSER'}.'@'.$self->{'DATAHOST'}.', DB '.$self->{'DBDATABASE'},
+		$self->{'last_stmt'};
 }
 
 sub piperr {
@@ -637,7 +641,7 @@ sub statement {
 		my $me = shift;
 		my($self,$db,$tm,$sth,$rd,$fh,$stmt,$stored,$rows) = @$me;
 		while(my $ref = $sth->fetchrow_arrayref) {
-			push(@$stored,$ref);
+			push(@$stored,[ @$ref ]);
 			$rows++;
 		}
 		$me->[8] = $rows;
@@ -645,6 +649,7 @@ sub statement {
 	}
 
 	sub DESTROY {
+		local $@;
 		my $me = shift;
 		my($self,$db,$tm,$sth,$rd,$fh,$stmt) = @$me;
 		my $bla = $sth->fetchrow_arrayref;
@@ -695,8 +700,7 @@ sub statement {
 
 	sub rows { shift->[4] }
 
-	sub DESTROY {
-	}
+	sub DESTROY { }
 }
 {
 	package Dbase::nix;
@@ -840,6 +844,7 @@ sub DbFunc {
 	}
 
 	sub DESTROY {
+		local $@;
 		my $me = shift;
 		my($self,$db,$tm) = @$me;
 		return unless ref $db; # schon vorbei
@@ -972,8 +977,10 @@ sub DbTrans {
 					$self->DbTransExit();
 					$self->{transact}->not_original(0);
 				} else {
-					$self->{transact}->fail;
-					$self->{transact}->done;
+					if ($self->{transact}) {
+						$self->{transact}->fail;
+						$self->{transact}->done;
+					}
 					fehler();
 				}
 			}
@@ -1148,6 +1155,7 @@ my $step = 0;
 		warnung "Die Sperre für '$lock' konnte nicht freigegeben werden ??\n" unless $rres;
 	}
 	sub DESTROY {
+		local $@;
 		my $me = shift;
 		$me->kill();
 	}
@@ -1275,6 +1283,7 @@ sub DbFree {
 }
 
 sub DESTROY {
+	local $@;
 	my $self = shift;
 	use Scalar::Util qw(reftype);
 	return unless reftype($self) eq 'HASH'; # Workaround, s. RT#244083
