@@ -61,4 +61,8 @@ has info => (
     predicate => 'has_info',
 );
 
+__PACKAGE__->meta->make_immutable;
+
+no Moose;
+
 1;
