@@ -17,6 +17,7 @@ our @EXPORT = qw(Do DoN DoT DoFn DoSeq isotime unixtime in_test date_add_ymd
 		sisodate isodate unixdate dbtime hash DelSeq qquote quote 
 		DoSelect DoSel DoCopy DoFree DoAtCommit DoTrans DoPing );
 our @EXPORT_OK = qw(
+  date_start
   DoBinary
   DoNonFatal
   DoTime
@@ -564,7 +565,7 @@ sub DoN ($) {
 	my($query) = @_;
 
 	ffehler {
-    	return $self->Do($query);
+    	return 0+$self->Do($query);
 	} sub {
 		return "-".join(" ",@fehler);
 	}
@@ -573,7 +574,7 @@ sub DoN ($) {
 sub Do ($) {
 	my $self = UNIVERSAL::isa($_[0],__PACKAGE__) ? shift : Dbase::db_handle();
 	my $query = $_[0];
-	$self->DbCmd($query);
+	0+$self->DbCmd($query);
 }
 
 sub DoT ($;&) {
@@ -985,6 +986,12 @@ sub in_test() {
 	return 3;
 }
 
+sub date_start($) {
+	my($date) = @_;
+	my($y,$m,$d,$hh,$mm,$ss) = isotime $date;
+	return unixtime($y,$m,$d, 0,0,0);
+}
+
 sub date_add_ymd($;$$$) {
 	my($date,$dy,$dm,$dd) = @_;
 	$dy ||= 0; $dm ||= 0; $dd ||= 0;
@@ -1002,6 +1009,7 @@ sub DoTime() {
 	if(not defined $last_local or $cur-$last_local>60){
 		$last_local=$cur;
 		$last_server=DoFn("select UNIX_TIMESTAMP(NOW())");
+		$last_server-=$ENV{'DATEFUDGE'} if defined $ENV{'DATEFUDGE'};
 	}
 	return $cur-$last_local+$last_server;
 }
@@ -1087,11 +1095,19 @@ sub like_list($;$@) {
 
     $not = $not ? ' NOT' : '';
 
-    if ( ( my @sql = map "$field$not LIKE " . qquote($_), @wildcards ) == 1 ) {
+    if (
+        (
+            my @sql =
+            map $field
+            . ( defined() ? "$not LIKE " . qquote($_) : " IS$not NULL" ),
+            @wildcards
+        ) == 1
+      )
+    {
         "@sql";
     }
     else {
-        '( ' . join( ' OR ', @sql ) . ' )';
+        '( ' . join( $not ? ' AND ' : ' OR ', @sql ) . ' )';
     }
 }
 
