@@ -778,19 +778,20 @@ sub status
 =item $obj-E<gt>B<children> ()
 
 Liefert eine (ggf. mehrdimensionale) Hashref der Kinder einer Hardware zurueck.
-Falls eine Hardware keine Kinder besitzt wird nur die ID der Hardware zurueck
-gegeben. Der Hash schaut ungefaehr so aus:
+Falls eine Hardware keine Kinder besitzt wird nur die ID und der Name der
+Hardware zurueck gegeben. Der Hash schaut ungefaehr so aus:
 
-  $children =
-  {
-    "[$hardware_id] $name" =>
-    {
-      "[$hardware_id] $name" => $id,
-      "[$hardware_id] $name" => $id,
-      .
-      :
-    },
-    "[$hardware_id] $name" => $id,
+  $children = {
+    "$id" => {
+        name     => "[$hardware_id] $name",
+        children => {
+            "$id" => { name => "[$hardware_id] $name", },
+            "$id" => { name => "[$hardware_id] $name", },
+            .
+            :
+        },
+      },
+    "$id" => { name => "$name [$hardware_id]", },
     .
     :
   };
@@ -807,7 +808,7 @@ sub children
 sub _get_chrildren
 {
 	my $id = shift;
-	my %childs = ();
+	my $childs;
 	my $ret = {};
 
 	DoSelect (sub
@@ -816,24 +817,19 @@ sub _get_chrildren
 			my $hid = shift;
 			my $name = shift;
 
-			$name = "[$hid] $name" if ($hid);
-			$childs{$name} = $cid;
+			$name .= " [$hid]" if ($hid);
+			$childs->{$cid} = $name;
 		}, qq(SELECT id, hardware_id, name FROM hardware WHERE enthalten_in = "$id")
 	);
 
-	if (!%childs)
-	{
-		return ($id);
-	}
-	else
-	{
-		for (keys (%childs))
-		{
-			my $name = $_;
-			$ret->{$name} = _get_chrildren ($childs{$name});
-		}
-		return ($ret);
+	return if !$childs;
+
+	for ( keys(%$childs) ) {
+		$ret->{$_}->{name} = $childs->{$_};
+		my $child = _get_chrildren($_);
+		$ret->{$_}->{children} = $child if defined $child;
 	}
+	return ($ret);
 }
 
 =item $obj-E<gt>B<remove_from_rack> ()
@@ -881,6 +877,96 @@ SQL
 	return (1);
 }
 
+=item I<%graph_links> = $obj-E<gt>B<ms_power_graph> ()
+
+Generiert die URL zu den Stromverbrauchsgraphen der Messstelle
+
+=cut
+
+sub ms_power_graphs {
+    my ( $self, $id) = @_;
+
+    my @pg;
+    my ( $msid, $sname, $tcollect, $ip_name ) = DoFn <<SQL;
+SELECT mess_stelle.id, mess_stelle.name, mess_typ.collectd_typ, ipkunde.name
+  FROM mess_stelle JOIN mess_typ ON mess_stelle.typ = mess_typ.id
+    JOIN ipkunde ON mess_stelle.snmp_host = ipkunde.id
+ WHERE mess_stelle.id = $id
+   AND ( ipkunde.ende IS NULL OR ipkunde.ende >= UNIX_TIMESTAMP(NOW()) )
+   AND ( mess_stelle.ende IS NULL OR mess_stelle.ende >= UNIX_TIMESTAMP(NOW()) )
+SQL
+
+    return () unless $msid;
+
+    my $cold =
+        'https://collect.noris.net/cgi-bin/collection3/bin/graph.cgi?'
+      . 'plugin=snmp;'
+      . 'end=' . time() . ';'
+      . "hostname=$ip_name;"
+      . "type=$tcollect;"
+      . "type_instance=$sname;";
+
+    my $day   = 'begin=' . ( time() - 86400 *   1 ) . ';';
+    my $week  = 'begin=' . ( time() - 86400 *   7 ) . ';';
+    my $month = 'begin=' . ( time() - 86400 *  31 ) . ';';
+    my $year  = 'begin=' . ( time() - 86400 * 365 ) . ';';
+
+    my %links = (
+        ms_id                => $msid,
+        ms_name              => $sname,
+        collectd_graph_day   => $cold . $day,
+        collectd_graph_week  => $cold . $week,
+        collectd_graph_month => $cold . $month,
+        collectd_graph_year  => $cold . $year,
+    );
+    return %links;
+}
+
+=item I<@collectd_links> = $obj-E<gt>B<power_graph> ()
+
+Generiert die URL zu den Stromverbrauchsgraphen eines Racks
+
+=cut
+
+sub power_graphs {
+    my $obj = shift;
+
+    my $cold =
+        'https://collect.noris.net/cgi-bin/collection3/bin/graph.cgi?'
+      . 'plugin=snmp;'
+      . 'begin=' . ( time() - 86400 * 31 ) . ';'
+      . 'end=' . time() . ';';
+
+    my $collect_link = "http://collect.noris.net/cgi-bin/collection3/bin/index.cgi?";
+
+    my @pg;
+    DoSelect(
+        sub {
+            my ( $vid, $msid, $sname, $tcollect, $ip_name ) = @_;
+            my $extra =
+                "hostname=$ip_name;"
+              . "type=$tcollect;"
+              . "type_instance=$sname;";
+
+            my %links = (
+                messstelle_id  => $msid,
+                collectd_graph => $cold . $extra,
+            );
+            push( @pg, \%links );
+        },
+        <<SQL);
+SELECT mess_verbraucher.id, mess_stelle.id, mess_stelle.name, mess_typ.collectd_typ, ipkunde.name
+  FROM mess_verbraucher JOIN mess_stelle ON mess_verbraucher.mess_stelle = mess_stelle.id
+    JOIN mess_typ ON mess_stelle.typ = mess_typ.id
+    JOIN ipkunde ON mess_stelle.snmp_host = ipkunde.id
+ WHERE mess_verbraucher.hardware = $obj->{'id'}
+   AND ( ipkunde.ende IS NULL OR ipkunde.ende >= UNIX_TIMESTAMP(NOW()) )
+   AND ( mess_stelle.ende IS NULL OR mess_stelle.ende >= UNIX_TIMESTAMP(NOW()) )
+SQL
+
+    return @pg;
+}
+
 =back
 
 =head1 SIEHE AUCH
