@@ -10,6 +10,7 @@ use Exporter;
 use strict;
 use utf8;
 use Carp;
+use List::Util qw(sum);
 use Text::ASCIITable::Wrap qw{ wrap };
 use overload '@{}' => 'addrow_overload', '""' => 'drawit';
 
@@ -900,6 +901,36 @@ sub draw {
 
 # nifty subs
 
+# Splits the $str in a list of text- and control-parts,
+# which always starts with an (possibly empty) text part:
+sub split_control_seqs_and_text {
+    my ( $self, $str ) = @_;
+    my @control_seqs;
+    push @control_seqs, qr/<.+?>/ if $self->{options}{allowHTML};
+    push @control_seqs,
+      qr/
+          \33
+          (?:
+              \[
+              (?:
+                  \d+
+                  (?:
+                      ;
+                      \d+
+                  )?
+              )?
+              [musfwhojBCDHRJK]
+            |
+              \(
+              [0B]
+          )
+        /x
+      if $self->{options}{allowANSI};
+    return $str unless @control_seqs;
+    my $re = qr/ ( (?: ${\ join '|', @control_seqs } )+ ) /x;
+    split $re, $str;
+}
+
 # Replaces length() because of optional HTML and ANSI stripping
 sub count {
   my ($self,$str) = @_;
@@ -913,11 +944,9 @@ sub count {
     $self->reperror("Error: 'cb_count' set but no valid callback found, found ".ref($self->{options}{cb_count}));
     return length($str);
   }
-  $str =~ s/<.+?>//g if $self->{options}{allowHTML};
-  $str =~ s/\33\[(\d+(;\d+)?)?[musfwhojBCDHRJK]//g if $self->{options}{allowANSI}; # maybe i should only have allowed ESC[#;#m and not things not related to
-  $str =~ s/\33\([0B]//g if $self->{options}{allowANSI};                           # color/bold/underline.. But I want to give people as much room as they need.
 
-  return length($str);
+  my $i = 0;
+  sum( map ++$i & 1 && length(), $self->split_control_seqs_and_text($str) ) || 0;
 }
 
 sub align {
