@@ -5,17 +5,13 @@ use strict;
 use warnings;
 
 use base 'Exporter';
-our @EXPORT_OK =
-  qw($Flag_rt_queue_rtweb $Status_Dead status_text user2customers);
+our @EXPORT_OK = qw(status_text user2customers);
 
 use Dbase::Globals qw(find_descr get_descr);
 use Dbase::Help qw(DoFn DoSelect qquote);
 use Memoize qw(memoize);
 use noris::REST::Backend qw(error);
 
-our $Flag_rt_queue_rtweb = find_descr rt_queue => 'rtweb', 1;
-our $Status_Dead         = find_descr tickets  => 'dead',  1;
-
 sub ticket_status($) { get_descr tickets => shift }
 memoize 'ticket_status';
 
