@@ -16,7 +16,7 @@ sub select_tickets {
     my ($self, %param) = @_;
     return noris::Ticket::API::RT::SelectResult->new(
         connection => $self, 
-        attributes => $param{attributes}, 
+        attributes => $param{attributes} || [], 
         query => $param{query},
     );
 }
