@@ -11,19 +11,12 @@ extends 'noris::Ticket::API::RT::Field::Standard';
 
 sub where_like {
     my $self = shift;
-    like_list( $self->db_name, '', _map_wildcards(@_) );
+    like_list( $self->db_name, '', $self->_map_wildcards(@_) );
 }
 
 sub where_like_not {
     my $self = shift;
-    like_list( $self->db_name, NOT => _map_wildcards(@_) );
-}
-
-sub _map_wildcards {
-    map {
-        y/*/%/;
-        $_;
-    } @_;
+    like_list( $self->db_name, NOT => $self->_map_wildcards(@_) );
 }
 
 1;
