@@ -4,13 +4,15 @@ use warnings;
 
 package noris::Ticket::API::RT::Field::URL;
 
+use Cf qw($RT_URL);
 use Moose;
 
 extends 'noris::Ticket::API::RT::Field';
 
 sub rt2api {
     my ( $self, $sql_value ) = @_;
-	"/rt/?display=History&serial_num=$sql_value";
+
+    $RT_URL . "/?display=History&serial_num=$sql_value";
 }
 
 1;
