@@ -32,6 +32,7 @@ use POSIX qw(locale_h strftime);
 use Email::Valid;
 use noris::MIME::Words qw(encode_mimewords);
 use Text::Wrap  qw(wrap);
+use Time::Zone qw(tz_local_offset);
 
 use Dbase ();
 use Dbase::Help qw(DoN DoFn DoSelect DoTrans qquote);
@@ -43,7 +44,7 @@ use Loader qw(log_update);
 use noris::Kunde qw(kundeid_get_all kundeid_get_by_flags);
 use noris::Person ();
 
-use constant SUBJECT_PREFIX => 'noris network Trouble Ticket: ';
+use constant SUBJECT_PREFIX => 'Trouble Ticket';
 
 @noris::TroubleTicket::EXPORT_OK = qw(tt_get_by_kunde tt_get_incomplete tt_get_descriptor_list);
 @noris::TroubleTicket::ISA = ('Exporter');
@@ -1305,10 +1306,11 @@ sub to_mail
 		return;
 	}
 
-	$subject = SUBJECT_PREFIX . $subject;
+	$subject = ": $subject";
 	if (defined (my $obj_ticket = $obj->get ('ticket'))) {
-		$subject .= " [noris #$obj_ticket]";
+		$subject = " [noris #$obj_ticket]$subject";
 	}
+	$subject = SUBJECT_PREFIX . $subject;
 
 	$mail = <<MAIL;
 Content-Type: text/plain; charset=utf-8
@@ -1316,6 +1318,7 @@ Content-Transfer-Encoding: 8bit
 From: support\@noris.net
 To: ${\ encode_mimewords($to) }
 Subject: ${\ encode_mimewords($subject) }
+Precedence: bulk
 
 MAIL
 
@@ -1340,12 +1343,13 @@ MAIL
 	my $ende   = $obj->get ('ende');
 
 	my $time_format = '%A, der %e. %B, %k:%M Uhr';
+	my $offset = sprintf '+%02X00', ( tz_local_offset() / 3600 );
 
 	$beginn = time () if (!$beginn);
 	$beginn = strftime ($time_format, localtime ($beginn));
 	if (defined ($ende))
 	{
-		$ende = strftime ($time_format, localtime ($ende));
+		$ende = strftime ($time_format, localtime ($ende)) . " $offset";
 	}
 	else
 	{
@@ -1357,7 +1361,7 @@ MAIL
 Ticket-Typ:         $type_info
 Störungsklasse:     $prio_info
 
-Start des Problems: $beginn
+Start des Problems: $beginn $offset
 Ende  des Problems: $ende
 
 MAIL
