@@ -25,7 +25,13 @@ use RT::support::mail qw(extract_mailaddresses);
 use RT::support::utils qw(parse_time
 		can_manipulate_request normalize_sn can_display_queue
 		can_display_request date_diff_ll can_add_time);
-use RT::ui::web::support qw(print_transaction get_msg req_url xstatus);
+use RT::ui::web::support qw(
+  get_msg
+  print_transaction
+  prio_color
+  req_url
+  xstatus
+);
 use RT::AddOns ();
 use RT::I18N qw(english_preferred);
 use Cf qw($BGCOLOR $DOCUSHARE $RT_DEFAULT_FIELDS $WDESCR);
@@ -133,10 +139,21 @@ sub DisplayForm($) {
 		if($request->param('transaction') and not $serial) {
 			($serial = $request->param('transaction')) =~ s/-.*//;
 			$serial = normalize_sn(int($serial));
-			$request->param('serial_num',$serial);
+			$request->param('serial_num',$serial) if defined $serial;
 		}
 		$display = "History";
 	}
+	if($display eq "History" and not $serial) {
+		## könnte im OTRS sein
+		delete local $ENV{TICKET_BACKENDS};
+		require noris::Ticket::API
+				and noris::Ticket::API->import('get_pooled_connection')
+			unless defined &get_pooled_connection;
+		my $conn = get_pooled_connection($ENV{REMOTE_USER});
+		my $ser = $request->param('serial_num');
+		$ser =~ y/0-9//cd;
+		$serial = $ser if defined $ser and $conn->get_ticket($ser);
+	}
 	if($display eq "History" and $serial) {
 		my $otrs = TicketID($serial);
 		if($otrs) {
@@ -357,11 +374,6 @@ sub TakeAction($) {
 		$request->param('date_fdue',$request->param('fdue_opt'));
 	}
 
-	if(defined $request->param('prio_tens') and defined $request->param('prio_ones')) {
-		$request->param('prio',$request->param('prio_tens').$request->param('prio_ones'));
-	} else {
-		$request->delete('prio');
-	}
 	my $subject = $request->param('subject');
 	if ( defined $subject ) {
 		$subject = decode_anything($subject);
@@ -405,7 +417,7 @@ sub TakeAction($) {
 	my $display = "History";
 
 	($trans, $StatusMsg) = change_priority ($serial, $request->param('prio'), $user)
-		if $action eq 'prio' and $request->param('prio');
+		if content( $request->param('prio') );
 
 	($trans, $StatusMsg) = steal ($serial, $user)
 		if $action eq 'steal' and $request->param('yes_do_it');
@@ -1013,7 +1025,27 @@ END
 			print tdf($fields,$count,$req{$temp}{since_told}) if $ff eq "l";
 			print tdf($fields,$count,$req{$temp}{since_told_l}) if $ff eq "L";
 			print tdf($fields,$count,$req{$temp}{area}) if $ff eq "m";
-			print tdf($fields,$count,$req{$temp}{priority}) if $ff eq "d";
+			print tdf(
+				$fields, $count,
+				{},
+				{
+					align   => 'center',
+					bgcolor => prio_color( $req{$temp}{priority} )
+				},
+				a(
+					{
+						href => req_url(
+							$request,
+							display    => 'SetPrio',
+							serial_num => $req{$temp}{effective_sn},
+							now        => $req{$temp}{date_acted},
+						),
+						target => $fields =~ /\*/ ? '_blank' : 'Ticket',
+					},
+					sprintf '%02d',
+					$req{$temp}{priority}
+				)
+			) if $ff eq 'd';
 			print tdf($fields,$count,$req{$temp}{status}) if $ff eq "e";
 			print tdf($fields,$count,$req{$temp}{age}) if $ff eq "f";
 			# print tdf($fields,$count,$req{$temp}{relevanz}) if $ff eq "r";
@@ -1111,6 +1143,7 @@ sub tdf($$@) {
 
 	my %args;
 	%args = %{shift()} if ref $_[0];
+	my %td_args = %{ +shift } if ref $_[0];
 	unless($args{size}) {
 		if($inf =~ /\+\+/) {
 			$args{size}="+1";
@@ -1127,7 +1160,7 @@ sub tdf($$@) {
 	my @cont = grep { defined $_ and $_ ne ""} @_;
 	@cont = ("&nbsp;") unless @cont;
 
-	td({nowrap=>undef},font(\%args,@cont));
+	td( { nowrap => undef, %td_args }, font( \%args, @cont ) );
 }
 
 sub display_history_tables($$) {
@@ -1516,7 +1549,7 @@ sub display_summary($$) {
 		    td({align=>"right"},
 			   a({href => req_url($request,display=>"SetPrio",now=>$acted,serial_num=>$serial)},
 			     b($en?"Current Priority":"aktuelle Priorität"))),
-			$spc,td(esc($req->{priority}))),
+			$spc, td( span({style=>'background-color:'.prio_color($req->{priority})}, sprintf '%02d', $req->{priority})) ),
 		  "\n",
 		  Tr({valign=>"top"},
 		    td({align=>"right"},
@@ -1696,8 +1729,8 @@ sub initialize_sn($) {
 		}
 	}
 	elsif (@ser > 1) { die "More than one serial_num: @ser\n" }
-	else {
-		$ser[0] =~ y/0-9//cd if defined $ser[0];
+	elsif (defined $ser[0]) {
+		$ser[0] =~ y/0-9//cd;
 		$request->param( serial_num => $ser[0] );
 	}
 	@ser;
