@@ -981,6 +981,10 @@ sub FormReply($;$){
 					select_a_date($req{$serial}{date_due}, 'due', $en))
 				)
 			),
+			Tr(
+				td( { align => 'right' }, $en ? 'Priority:' : 'Priorität:' ),
+				td( select_an_int( $req{$serial}{priority}, 'prio' ) ),
+			  ),
 			Tr(
 				td({align=>'right'}, 'Info:'),
 				td(textfield('info',$req{$serial}{info},60,255)),
@@ -1210,7 +1214,7 @@ sub FormComment($){
 				td(popup_menu("queue_new",
 				   [ ("--",grep {$_ !~ /^\d+$/ and can_create_request($_,$user,1)>0 } sort { lc($a) cmp lc($b) } keys %queues )],"--",{"--" => $en?"Current Request":"aktueller Request"}))),
 			Tr({id => 'area'},
-				td( { align => 'right' }, $en ? 'Area' : 'Bereich' ),
+				td( { align => 'right' }, $en ? 'Area:' : 'Bereich:' ),
 				td(
 					popup_menu(
 						'area',
@@ -1233,6 +1237,10 @@ sub FormComment($){
 					select_a_date($req{$serial}{date_due}, 'due', $en))
 				)
 			),
+			Tr(
+				td( { align => 'right' }, $en ? 'Priority:' : 'Priorität:' ),
+				td( select_an_int( $req{$serial}{priority}, 'prio' ) ),
+			  ),
 			Tr(
 				td({align=>'right'}, 'Info:'),
 				td(textfield('info',$req{$serial}{info},60,255)),
