@@ -15,6 +15,7 @@ use vars qw(@EXPORT_OK @ISA);
 	get_msg
 	info4kunde
 	print_transaction
+	prio_color
 	req_url
 	rt_footer
 	rt_header
@@ -31,9 +32,11 @@ use Cf qw(
   $RT_DOMAIN
   $RT_IGNORE_PARAMETERS
   $TICKET_DOMAIN
+  $WDESCR
 );
 use CGI qw(:standard :any object center);
 use Dbase::Help qw(DoFn qquote);
+use Memoize qw(memoize);
 use RT::I18N qw(english_preferred);
 use RT::MIME qw(mime_parse);
 use URI ();
@@ -55,9 +58,26 @@ sub esc_h($) {
 	# esc(scalar decode_mimewords($txt));
 	# Wir brauchen das decode_anything, weil der decode()-Aufruf evtl. ISO-8859-1
 	# zurückliefert.
-	esc(decode_anything(Encode::decode("MIME-Header", $txt)));
+	my $new_txt;
+	eval {
+		$new_txt = Encode::decode("MIME-Header", $txt);
+	};
+	$new_txt = $txt if $@;
+	esc(decode_anything($new_txt));
 }
 
+sub ticket_url($) {
+    my ($tn) = @_;
+    delete local $ENV{TICKET_BACKENDS};
+    require noris::Ticket::API
+      and noris::Ticket::API->import('get_pooled_connection')
+      unless defined &get_pooled_connection;
+    my ($ticket_url) =
+      get_pooled_connection()->get_ticket( $tn, ['ticket_url'] );
+    $ticket_url;
+}
+memoize('ticket_url');
+
 # Flags & 1 => kein Einbauen von Links (benötigt für <title>-Header)
 sub esc($;$$) {
 	my ( $txt, $request, $flags ) = @_;
@@ -67,8 +87,45 @@ sub esc($;$$) {
 	$txt = CGI::escapeHTML(decode_anything($txt));
 
 	unless ( $flags & 1 ) {
-		my @txt = split
-		  /(\bRT#(\d+)(?:-(\d+))?\b|\b(\d+)\@(\Q$TICKET_DOMAIN\E|\Q$RT_DOMAIN\E)\b|\[\[(.*?)\]\])/,
+		my @txt = split /
+            (                                            # (gesamter Link)
+                \b
+                RT\#
+                ([1-9][0-9]*)                            # RT#<4711>
+                (?:
+                    -
+                    ([1-9][0-9]*)                        # RT#4711-<42>
+                )?
+                \b
+              |
+                \b
+                ([1-9][0-9]*)                            # <4711>@...
+                \@
+                ( \Q$TICKET_DOMAIN\E | \Q$RT_DOMAIN\E )  # 4711@<...>
+                \b
+              |
+                \[
+				\Q$WDESCR\E
+				\s
+				\#
+				([1-9][0-9]*)                            # [noris #<12345678>]
+				\]
+              |
+                \b
+                [Tt]icket\s*
+                ( \d{1,13} )                             # 123456789 (ticket number)
+                \b
+             |
+                \b
+                Artikel\s+
+                ( \d{1,13} )                             # Artikel 123456789 (article number)
+                \b
+             |
+                \[\[
+                (.*?)                                    # [[<Seite>]]
+                \]\]
+            )
+		/x,
 		  $txt;
 
 		$txt = '';
@@ -84,12 +141,13 @@ sub esc($;$$) {
 				$txt .= $text;
 			}
 
-			# elsif ( @txt < 5 ) { die }
+			# elsif ( @txt < 6 ) { die }
 			# nein, denn split() lässt undef-Werte am Ende der Liste weg
 
 			else {
-				my ( $text, $ticket1, $seq, $ticket2, $domain, $wikiseite ) =
-				  splice @txt, 0, 6;
+				my ( $text, $ticket1, $seq, $ticket2, $domain, $ticket3,
+					$ticket4, $artikel, $wikiseite )
+				  = splice @txt, 0, 9;
 				$txt .= defined $wikiseite
 				  ? '[[' . a(
 					{
@@ -100,18 +158,36 @@ sub esc($;$$) {
 							# mit "/" als zusätzlicher Ausnahme,
 							# vgl. Ticket #10033731:
 							'^A-Za-z0-9\-_.!~*’()/'
-						)
+						),
+						target => 'Wiki',
 					},
 					$wikiseite
 				  )
 				  . ']]'
-				  : defined $domain && $domain eq $TICKET_DOMAIN ? a(
+				  : defined $domain || defined $ticket3
+				  ? do {
+					if (
+						defined(
+							my $ticket_url = ticket_url(
+								defined $ticket2 ? $ticket2 : $ticket3
+							)
+						)
+					  )
 					{
-						href =>
-"/otrs/index.fpl?Action=AgentTicketZoom&TicketNumber=$ticket2"
-					},
-					$text
-				  )
+						a( { href => $ticket_url, target => 'Ticket' }, $text );
+					}
+					else { $text }
+				  }
+				  : defined $ticket4
+				  ? do {
+					if ( defined( my $ticket_url = ticket_url( $ticket4 ) ) ) {
+						a( { href => $ticket_url, target => 'Ticket' }, $text );
+					}
+					else { $text }
+				  }
+				  : defined $artikel
+				  ? 
+						a( { href => '/otrs/index.pl?Action=AgentTicketZoom&ArticleID='.$artikel, target => 'Ticket' }, $text )
 				  : a(
 					{
 						href => req_url(
@@ -409,35 +485,18 @@ sub print_mime($$$$$) {
 	@res;
 }
 
-	
-#sub dump_env($) {
-## Get the input
-#	my($request) = @_;
-#    foreach $pair (%ENV)    {
-#		print STDERR "$pair\n";
-#	
-#    }
-#    foreach $pair (%FORM)    {
-#		print STDERR "$pair\n";
-#    }
-#}
-#
-
+# Wird effektiv nur für Prioritäten verwendet:
 sub select_an_int($$) {
     my ($default, $name) = @_;
-	$default = 0 unless $default;
-    my ($ones, $tens, $counter);
-	use integer;
-
-    $tens = $default / 10;
-    $ones = $default % 10;
-
-	Select({name => $name."_tens"},
-		map { $tens == $_ ? option({selected => undef}, $_) : option($_) } 0..9
-	).
-	Select({name => $name."_ones"},
-		map { $ones == $_ ? option({selected => undef}, $_) : option($_) } 0..9
-	);
+	$default = sprintf '%02d', $default || 0;
+	Select(
+		{ name => $name },
+		map $default == $_
+		? option( { value => 0+$_, selected => undef }, $_ )
+		: option( { value => 0+$_                    }, $_ ),
+		'00' .. '05',
+		10 .. 50
+	  )
 }
 
 my @MoY = ('Jan','Feb','Mar','Apr','May','Jun',
@@ -495,6 +554,22 @@ sub select_a_date($$;$$) {
 	;
 }
 
+sub otrs_disclaimer {
+	my $request = shift;
+	$request->table(
+		{ bgcolor => '#FF9999', cellpadding => 8, width => '100%' },
+		$request->Tr(
+			$request->td(
+				{ align => 'center', style => 'font-size:3em' },
+				'Hier gibt es nichts (mehr) zu sehen.'
+				  . $request->br
+				  . 'Bitte gehen Sie weiter '
+				  . $request->a( { href => '/otrs/' }, 'zum OTRS' ) . '!'
+			)
+		)
+	  ),
+	  ;
+}
 
 sub rt_header($@) {
 	my ($request,@args) = @_;
@@ -513,7 +588,8 @@ sub rt_header($@) {
 	                            -dtd => "-//W3C//DTD HTML 3.2//EN",
 	                            -title   => esc( $title, undef, 1 ),
 	                            @scr,
-                                  );
+                                  ),
+	      otrs_disclaimer($request), $request->br;
 }
 
 sub rt_footer($) {
@@ -529,10 +605,8 @@ sub rt_footer($) {
 			$en?"Be careful not to leave yourself logged in from a ":"Nach der Arbeit über öffentlich zugängliche Browser",
 			b($en?"public terminal":"immer ausloggen!")
 		),br(),
-		$en?"Please report all bugs to ":"Alle Fehlermeldungen an ",
-		a({href => "mailto:rt\@rt.noris.net"}, $en?"the RT support queue":"die RT-Support-Queue"),
-		"."
     ),
+	otrs_disclaimer($request),
 	$request->end_html()."\n";
 	if ( defined $ENV{PATH_INFO} and $ENV{PATH_INFO} =~ /debug/ ) {
 		print "\n<hr><plaintext>\n";
@@ -612,4 +686,13 @@ _
 
 sub user_param() { qw(fup max_sequences nst rev show_all_headers) }
 
+sub prio_color($) {
+    my ($prio) = @_;
+    !$prio         ? 'bbddff'
+      : $prio < 10 ? 'ffbbbb'
+      : $prio < 20 ? 'ffeebb'
+      : $prio < 30 ? 'ddffdd'
+      :              'eeeeee';
+}
+
 1;
